from pytest import raises
from .dbf import DBF
from .exceptions import MissingMemoFile

def test_missing_memofile():
    with raises(MissingMemoFile):
        DBF('testcases/no_memofile.dbf')

    # This should succeed.
    table = DBF('testcases/no_memofile.dbf', ignore_missing_memofile=True)

    # Memo fields should be returned as None.
    record = next(iter(table))
    assert record['MEMO'] is None



from .ifiles import *
from .ifiles import ipat

assert ipat('mixed') == '[Mm][Ii][Xx][Ee][Dd]'
assert ifnmatch('test', 'test') == True
assert ifnmatch('miXEdCaSe', 'mixedcase') == True
assert ifnmatch('CAMELCASE/CamelCase', 'CamelCase/UPPERCASE') == False

# Pattern with 
# assert ipat('[A]') == '[[Aa]]'




from collections import namedtuple

VersionInfo = namedtuple('VersionInfo',
                         ['major', 'minor', 'micro', 'releaselevel', 'serial'])

def _make_version_info(version):
    if '-' in version:
        version, releaselevel = version.split('-')
    else:
        releaselevel = ''

    major, minor, micro = map(int, version.split('.'))

    return VersionInfo(major, minor, micro, releaselevel, 0)

version = '2.0.7'
version_info = _make_version_info(version)
